#!/usr/bin/env python
from setuptools import setup

setup(
    name='little-sandbox-py',
    version='1.0.6',
    description='A sandbox for running python scripts',
    url='https://github.com/Hustcw/Little-Sandbox',
    author='hustcw',
    license='MIT',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    keywords='sandbox docker python',
    packages=['sandbox'],
)
